[asterisk-commits] oej: trunk r42767 - /trunk/channels/chan_sip.c

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Mon Sep 11 12:14:58 MST 2006


Author: oej
Date: Mon Sep 11 14:14:58 2006
New Revision: 42767

URL: http://svn.digium.com/view/asterisk?rev=42767&view=rev
Log:
More formatting

Modified:
    trunk/channels/chan_sip.c

Modified: trunk/channels/chan_sip.c
URL: http://svn.digium.com/view/asterisk/trunk/channels/chan_sip.c?rev=42767&r1=42766&r2=42767&view=diff
==============================================================================
--- trunk/channels/chan_sip.c (original)
+++ trunk/channels/chan_sip.c Mon Sep 11 14:14:58 2006
@@ -1943,7 +1943,7 @@
 	p->autokillid = -1;
 
 	if (option_debug)
-		ast_log(LOG_DEBUG, "Auto destroying call '%s'\n", p->callid);
+		ast_log(LOG_DEBUG, "Auto destroying SIP dialog '%s'\n", p->callid);
 	append_history(p, "AutoDestroy", "%s", p->callid);
 	if (p->owner) {
 		ast_log(LOG_WARNING, "Autodestruct on dialog '%s' with owner in place (Method: %s)\n", p->callid, sip_methods[p->method].text);
@@ -1956,7 +1956,7 @@
 	return 0;
 }
 
 /*! \brief Schedule destruction of SIP call */
 static void sip_scheddestroy(struct sip_pvt *p, int ms)
 {
 	if (ms < 0) {
@@ -2075,7 +2075,7 @@
 	parse_request(dst);
 }
 
-/* add a blank line if no body */
+/*! \brief add a blank line if no body */
 static void add_blank(struct sip_request *req)
 {
 	if (!req->lines) {
@@ -1956,7 +1956,7 @@
 }
 
-/*! \brief Schedule destruction of SIP call */
+/*! \brief Schedule destruction of SIP dialog */
 static void sip_scheddestroy(struct sip_pvt *p, int ms)
 {



More information about the asterisk-commits mailing list